iamai.adapter package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   iamai.adapter.apscheduler
   iamai.adapter.bililive
   iamai.adapter.console
   iamai.adapter.cqhttp
   iamai.adapter.dingtalk
   iamai.adapter.gensokyo
   iamai.adapter.kook
   iamai.adapter.red

Submodules
----------

.. toctree::
   :maxdepth: 4

   iamai.adapter.utils

Module contents
---------------

.. automodule:: iamai.adapter
   :members:
   :undoc-members:
   :show-inheritance:
